==> influence-0.1.tar.gz: influence-0.1/setup.py <==
from distutils.core import setup

setup(
  name = 'influence',         # How you named your package folder (MyLib)
  packages = ['influence'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A utility package for python containing two sub-packages that 1. extend python, and 2. add to python',   # Give a short description about your library
  author = 'Neil',                   # Type in your name
  author_email = 'nghugare2@outlook.com',      # Type in your E-Mail
  url = 'https://github.com/RandomKiddo/influence',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/RandomKiddo/influence/archive/v01.tar.gz',    # I explain this later on
  keywords = ['PYTHON', 'EXTENDER', 'UPGRADER'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'matplotlib',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.8',
  ],
)

==> influence-0.3.tar.gz: influence-0.3/setup.py <==
from distutils.core import setup

setup(
  name = 'influence',         # How you named your package folder (MyLib)
  packages = ['influence'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A utility package for python containing two sub-packages that 1. extend python, and 2. add to python',   # Give a short description about your library
  long_description = 'See https://github.com/RandomKiddo/influence',
  author = 'Neil',                   # Type in your name
  author_email = 'nghugare2@outlook.com',      # Type in your E-Mail
  url = 'https://github.com/RandomKiddo/influence',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/RandomKiddo/influence/archive/v_03.tar.gz',    # I explain this later on
  keywords = ['PYTHON', 'EXTENDER', 'UPGRADER'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'matplotlib',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.8',
  ],
)
